package net.wanji.common.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Objects;

/**
 * @author wanji
 * @version 1.0
 * Created on 2019/4/16 15:07
 * @Description: [枚举类]
 */
public class BaseEnum {

    /**
     * @author wanji
     * @description: [操作日志类型枚举]
     * @date 2019/4/17 14:09
     */
    public enum OperationTypeEnum {
        INSERT, UPDATE, QUERY, DELETE
    }

    /**
     * @author wanji
     * @description: [状态]
     * @date 2019/4/19 18:01
     */
    @Getter
    @AllArgsConstructor
    public enum StatusEnum {
        ON(1, "在线/有效"),
        OFF(2, "下线/无效");

        private Integer code;

        private String name;
    }

    /**
     * @author wanji
     * @description: [厂商类型枚举类]
     * @date 2019/4/19 18:01
     */
    @Getter
    @AllArgsConstructor
    public enum VendorTypeEnum {
        QS(1, "青松", "QS"),
        SCATS(2, "SCATS", "SCATS"),
        HS(3, "海信", "HISENSE"),
        HK(4, "海康", "HK"),
        JA(5, "京安", "JA"),
        TA(6, "同安", "TA"),
        TSC(7, "励安","TSC"),
        DT(8, "东土","DT"),
        LES(9, "莱斯","LES");

        private Integer code;

        private String name;

        private String nick;

        public static VendorTypeEnum getNameByCode(int code) {
            for (VendorTypeEnum vendorTypeEnum : VendorTypeEnum.values()) {
                if (vendorTypeEnum.getCode() == code) {
                    return vendorTypeEnum;
                }
            }
            return null;
        }

        public static VendorTypeEnum getNameByNick(String nick) {
            for (VendorTypeEnum vendorTypeEnum : VendorTypeEnum.values()) {
                if (vendorTypeEnum.getNick().equals(nick)) {
                    return vendorTypeEnum;
                }
            }
            return null;
        }
    }

    @Getter
    @AllArgsConstructor
    public enum VendorMethodCodeEnum {
        QS("1", "路口列表数据获取"),
        SCATS("1", "SCATS"),
        HS("1", "海信"),
        HK("1", "海康");

        private String code;

        private String name;

        public static VendorMethodCodeEnum getNameByCode(String code) {
            for (VendorMethodCodeEnum methodTypeEnum : VendorMethodCodeEnum.values()) {
                if (methodTypeEnum.getCode().equals(code)) {
                    return methodTypeEnum;
                }
            }
            return null;
        }
    }

    /**
     * @author wanji
     * @description: [信号方向枚举类]
     * @date 2019/4/19 18:01
     */
    @Getter
    @AllArgsConstructor
    public enum SignalDirectionEnum {
        N(1, "北", "N"),
        EN(2, "东北", "EN"),
        E(3, "东", "E"),
        ES(4, "东南", "ES"),
        S(5, "南", "S"),
        WS(6, "西南", "WS"),
        W(7, "西", "W"),
        WN(8, "西北", "WN");

        private Integer code;

        private String name;

        private String nick;

        public static SignalDirectionEnum getNickByCode(int code) {
            for (SignalDirectionEnum signalDirectionEnum : SignalDirectionEnum.values()) {
                if (signalDirectionEnum.getCode() == code) {
                    return signalDirectionEnum;
                }
            }
            return null;
        }

        public static String getNameByCode(int code) {
            for (SignalDirectionEnum signalDirectionEnum : SignalDirectionEnum.values()) {
                if (signalDirectionEnum.getCode() == code) {
                    return signalDirectionEnum.getName();
                }
            }
            return null;
        }

        public static SignalDirectionEnum getNameByNick(String nick) {
            for (SignalDirectionEnum signalDirectionEnum : SignalDirectionEnum.values()) {
                if (signalDirectionEnum.getNick().equals(nick)) {
                    return signalDirectionEnum;
                }
            }
            return null;
        }

        public static Integer getCodeByName(String name) {
            for (SignalDirectionEnum signalDirectionEnum : SignalDirectionEnum.values()) {
                if (Objects.equals(signalDirectionEnum.getName(), name)) {
                    return signalDirectionEnum.getCode();
                }
            }
            return null;
        }

    }

    @Getter
    @AllArgsConstructor
    public enum StepTypeEnum {

        //步类型：1-机动车/行人同时绿灯 2-机动车绿灯/行人绿闪 3-机动车/行人同时绿闪 4-黄灯 5-红灯 6-关灯 7-黄闪 8-红闪
        GREEN(1, "机动车/行人同时绿灯"),

        PEDESTRIAN_GREEN_FLASH(2, "机动车绿灯/行人绿闪"),

        GREEN_FLASH(3, "机动车/行人同时绿闪"),

        YELLOW(4, "黄灯"),

        RED(5, "红灯"),

        OFF(6, "关灯"),

        YELLOW_FLASH(7, "黄闪"),

        RED_FLASH(8, "红闪");

        private Integer type;

        private String name;

        /**
         * 根据code返回枚举值
         *
         * @param type
         * @return
         */
        public static StepTypeEnum getEnumByType(int type) {
            for (StepTypeEnum testEnums : StepTypeEnum.values()) {
                if (testEnums.getType() == type) {
                    return testEnums;
                }
            }
            return null;
        }

    }


    @Getter
    @AllArgsConstructor
    public enum TurnTypeEnum {

        //步类型：1-左转 2-直行 3-右转 4-调头
        LEFT(1, "l", "左转"),

        STRAIGHT(2, "s", "直行"),

        RIGHT(3, "r", "右转"),

        TURN(4, "u", "调头"),

        ALL(5, "all", "圆饼灯"),

        PEDESTRIAN(6, "pedestrian", "行人"),

        ONCE_PEDESTRIAN(7, "once_pedestrian", "一次行人"),

        TWO_PEDESTRIAN(8, "two_pedestrian", "二次行人");


        private Integer intCode;
        private String strCode;
        private String name;

        /**
         * 根据code返回枚举值
         *
         * @param type
         * @return
         */
        public static TurnTypeEnum getEnumByType(int type) {
            for (TurnTypeEnum testEnums : TurnTypeEnum.values()) {
                if (testEnums.getIntCode() == type) {
                    return testEnums;
                }
            }
            return null;
        }

        public static Integer getIntCodeByStrCode(String strCode) {
            for (TurnTypeEnum testEnums : TurnTypeEnum.values()) {
                if (Objects.equals(testEnums.getStrCode(), strCode)) {
                    return testEnums.getIntCode();
                }
            }
            return null;
        }

        public static String getNameByCode(Integer turn) {
            for (TurnTypeEnum testEnums : TurnTypeEnum.values()) {
                if (Objects.equals(testEnums.getIntCode(), turn)) {
                    return testEnums.getName();
                }
            }
            return null;
        }

    }

    /**
     * @author wanji
     * @description: [车辆类型枚举类]
     * @date 2019/4/19 18:01
     */
    @Getter
    @AllArgsConstructor
    public enum VehicleTypeEnum {
        LARGE_VEHICLE("01", "大型车辆"),
        MEDIUM_VEHICLE("02", "中型车辆"),
        SMALL_VEHICLE("03", "小型车辆"),
        MICRO_VEHICLE("04", "微型车辆"),
        TRICYCLE("05", "三轮车"),
        MOTORCYCLE("06", "摩托车"),
        POLICE_VEHICLE("07", "警用车辆"),
        FOREIGN_VEHICLE("08", "外籍车辆"),
        OTHER("99", "其他");

        private String code;
        private String name;

        public static String getNameByCode(int code) {
            for (SignalDirectionEnum signalDirectionEnum : SignalDirectionEnum.values()) {
                if (signalDirectionEnum.getCode() == code) {
                    return signalDirectionEnum.getName();
                }
            }
            return "";
        }
    }


    @Getter
    @AllArgsConstructor
    public enum ColorTypeEnum {
        GREEN(1, "++g", "绿色"),

        YELLOW(2, "+y+", "黄色"),

//        RED(3, "++g", "红色"),

        OFF(10, "+++", "关闭");

        private Integer code;

        private String type;

        private String name;

        public static String getTypeByCode(int code) {
            for (ColorTypeEnum colorTypeEnum : ColorTypeEnum.values()) {
                if (colorTypeEnum.getCode() == code) {
                    return colorTypeEnum.getType();
                }
            }
            return "";
        }
    }


    @Getter
    @AllArgsConstructor
    public enum LampStatusEnum {

        GREEN("绿灯", "green"),
        GREEN_FLASH("绿闪", "greenFlash"),
        YELLOW("黄灯", "yellow"),
        YELLOW_FLASH("黄闪", "yellowFlash"),
        RED("红灯", "red"),
        RED_FLASH("红闪", "redFlash"),
        LIGHTS_OUT("熄灯", "lightsOut");


        private String name;

        private String code;

        public static String getTypeByCode(String code) {
            for (LampStatusEnum lampStatusEnum : LampStatusEnum.values()) {
                if(lampStatusEnum.getCode().equals(code)){
                    return lampStatusEnum.getName();
                }
            }
            return "";
        }
    }

    /**
     * @author wanji
     * @description: [信号中心控制枚举类]
     * @date 2019/4/19 18:01
     */
    @Getter
    @AllArgsConstructor
    public enum SignalControlModeEnum {
        //控制类型
        NO_CABLE(1,"无电缆控制"),
        ONLINE(2,"区域协调控制"),
        MANUAL(3,"手控模式"),
        NO_CABLE_TRUNK_(4,"无电缆干线协调控制"),
        NO_CABLE_INDUCTION(5,"无电缆式感应控制"),
        FULL_INDUCTION(6,"全感应控制"),
        HALF_INDUCTION(7,"单点感应控制"),
        DYNAMIC_PLAN(8,"单点自适应控制"),
        SCHEDULE(9,"时间表控制"),
        URGENT(10,"紧急呼叫模式"),
        SECRET_SERVICE(11,"特勤模式"),
        START_MODE(12,"启动模式"),
        SPECIAL(13,"特殊控制"),
        PEDESTRIAN_CROSSING(14,"行人过街信号控制模式"),
        BUS_PRIORITY(15,"公交优先控制模式"),
        FLOW_CONTROL(16,"调仓控流环保信号控制模式"),
        VARIABLE_LANE(17,"可变车道的信号控制模式"),
        DEMAND_SENSING(18,"请求式感应信号控制模式"),
        OVERFLOW(19,"路口防溢出信号控制模式"),
        TRUNK(20,"干线协调信号控制模式"),
        MOBILE_SIGNAL(21,"集装箱移动式信号控制模式"),
        FLASH(22,"闪光控制"),
        UNCOORDINATED_PHASE(23,"非协调相位顺序监控模式"),
        COORDINATED_PHASE(24,"协调相位优先顺序监控模式"),
        COORDINATED_PHASE_NORETURN(25,"协调相位不再返回模式"),
        UNCOORDINATED_PHASE_CONTINUOUS(26,"非协调相位连续顺序监控模式"),
        CENTER_SCHEDULE(27,"中心主控降级多时段"),
        CENTER_HALF_INDUCTION(28,"中心主控降级自适应"),
        TEMPORARY_PLAN(29,"临时方案控制"),
        OTHER_USER(30,"定周期控制");


        private Integer type;

        private String name;

        /**
         * 根据code返回枚举值
         *
         * @param type
         * @return
         */
        public static SignalControlModeEnum getEnumByType(int type) {
            for (SignalControlModeEnum testEnums : SignalControlModeEnum.values()) {
                if (testEnums.getType() == type) {
                    return testEnums;
                }
            }
            return null;
        }
    }


    /**
     * @author wanji
     * @description: [信号中心控制-运行模式枚举类]
     * @date 2019/4/19 18:01
     */
    @Getter
    @AllArgsConstructor
    public enum SignalRunModeEnum {
        //控制类型
        //2	手动锁定当前相位
        //3	手动全红
        //4	手动黄闪
        //5	手动关灯
        //6	全红闪控制
        //8	正常按计划运行
        //9	手动步进控制
        //10 自动步进控制
        //11 恢复时间表
        //255 临时控制方案

        LOCK_PHASE(2, "相位锁定"),

        ALL_RED(3, "全红控制"),

        YELLOW_FLASH(4, "全黄闪控制"),

        OFF(5, "关灯控制"),

        RED_FLASH(6, "全红闪控制"),

        ALL_YELLOW(7, "全黄控制"),

        NORMAL_PLAN(8, "按正常计划运行"),

        STEP_CONTROL(9, "步进控制"),

        AUTO_STEP_CONTROL(10, "自动步进控制"),

        RECOVER_SCHEDULE(11, "恢复时间表"),

        OTHER_USER_CONTROL(56, "其它账号控制运行"),

        TEMPORARY_PLAN(255, "临时控制方案");

        private Integer type;

        private String name;

        /**
         * 根据code返回枚举值
         *
         * @param type
         * @return
         */
        public static SignalRunModeEnum getEnumByType(int type) {
            for (SignalRunModeEnum testEnums : SignalRunModeEnum.values()) {
                if (testEnums.getType() == type) {
                    return testEnums;
                }
            }
            return null;
        }
    }
}
