package net.wanji.common.utils.tool;

import java.text.MessageFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * @author Kent HAN
 * @date 2022/11/3 16:29
 */
public class TimeArrayUtil {

    /**
     * 返回一天的小时数组，按小时。如 ["00:00", "01:00" ... "23:00"]
     *
     * @author Kent HAN
     * @date 2022/11/3 16:30
     */
    public static List<String> getHourArray() {
        List<String> res = new ArrayList<>();
        for (int i = 0; i < 24; i++) {
            if (i < 10) {
                res.add(MessageFormat.format("0{0}:00", i));
            } else {
                res.add(i + ":00");
            }
        }
        return res;
    }

    public static List<String> getHourArrayScope(int startHour, int endHour) {
        List<String> res = new ArrayList<>();
        for (int i = startHour; i <= endHour; i++) {
            if (i < 10) {
                res.add(MessageFormat.format("0{0}:00", i));
            } else {
                res.add(i + ":00");
            }
        }
        return res;
    }

    /**
     * 按分钟段返回一天的时间数组。如 ["00:15", "00:30" ... ]
     * minutes，分钟段。如按每15分钟生成，则 minute 传15。
     * @author Kent HAN
     * @date 2022/11/3 16:30
     */
    public static List<String> getMinuteSectionArray(Integer minutes) {
        List<String> timeSegments = new ArrayList<>();
        SimpleDateFormat sdf = new SimpleDateFormat("HH:mm");
        for (int i = 0; i < 24 * 60; i += minutes) {
            Date date = new Date();
            date.setHours(i / 60);
            date.setMinutes(i % 60);
            timeSegments.add(sdf.format(date));
        }
        return timeSegments;
    }

    /**
     * 按分钟段返回指定区间的时间数组。如 ["00:15", "00:30" ... ]
     * minutes，分钟段。如按每15分钟生成，则 minute 传15。
     * @author Kent HAN
     * @date 2022/11/3 16:30
     */
    public static List<String> getCustomTimeIntervals(String startHourMinuteStr, String endHourMinuteStr, Integer minutes) {
        int startMinutes = convertToMinutes(startHourMinuteStr);
        int endMinutes = convertToMinutes(endHourMinuteStr);

        List<String> res = new ArrayList<>();
        for (int currentMinutes = startMinutes; currentMinutes <=endMinutes; currentMinutes += minutes) {
            res.add(convertToHourMinuteStr(currentMinutes));
        }

        return res;
    }

    private static int convertToMinutes(String hourMinuteStr) {
        String[] parts = hourMinuteStr.split(":");
        int hours = Integer.parseInt(parts[0]);
        int minutes = Integer.parseInt(parts[1]);
        return hours * 60 + minutes;
    }

    private static String convertToHourMinuteStr(int minutes) {
        int hours = minutes / 60;
        minutes %= 60;
        return String.format("%02d:%02d", hours, minutes);
    }

    public static void main(String[] args) {
        String startHourMinuteStr = "07:00";
        String endHourMinuteStr = "9:10";
        Integer intervalMinutes = 5;

        List<String> intervals = getCustomTimeIntervals(startHourMinuteStr, endHourMinuteStr, intervalMinutes);

        for (String interval : intervals) {
            System.out.println(interval);
        }
    }

    /**
     * 跨天生成时间数组。如 ["23:55", "00:00" ... ]
     * minutes，分钟段。如按每15分钟生成，则 minute 传15。
     * @author Kent HAN
     * @date 2022/11/3 16:30
     */
    public static List<String> getMultiDayTimeIntervals(Date boStartTime, Date boEndTime, int minutes) {
        List<String> intervals = new ArrayList<>();
        SimpleDateFormat sdf = new SimpleDateFormat("HH:mm");
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(boStartTime);

        while (!calendar.getTime().after(boEndTime)) {
            intervals.add(sdf.format(calendar.getTime()));
            calendar.add(Calendar.MINUTE, minutes);
        }

        return intervals;
    }
}
